﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Diagnostics;

using Popolo.HVAC.HeatSource;

namespace SampleProgram
{
  class Program
  {

    static void Main(string[] args)
    {
      double mchw = 54d / 60;
      double mcdw = 127d / 60d;
      double mhw = 64.5 / 60;
      double cop = 0.47;
      double qch = 8.8;
      double qh = qch / cop;
      double qcd = qch + qh;
      double tchi = 22;
      double thi = 55;
      double tcdi = 27;
      double tcho = tchi - qch / (4.186 * mchw);
      double tho = thi - qh / (4.186 * mhw);
      double tcdo = tcdi + qcd / (4.186 * mcdw);
      AdsorptionChiller ads = new AdsorptionChiller(tchi, tcho, mchw, tcdi, tcdo, mcdw, thi, tho, mhw);

      using (StreamWriter sWriter = new StreamWriter
        ("adsorptionChillerTest.csv", false, Encoding.GetEncoding("Shift_JIS")))
      {

        sWriter.WriteLine("温水入口温度, 冷水流量比[-], COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i += 5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw * rt, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 20; i <= 28; i++)
          {
            ads.Update(i, mchw, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + i + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 温水流量, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i += 5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw, 27, mcdw, thw, mhw * rt);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("冷却水入口温度, 温水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int i = 24; i <= 33; i += 3)
        {
          for (int thw = 45; thw <= 60; thw++)
          {
            ads.Update(22, mchw, i, mcdw, thw, mhw);
            sWriter.WriteLine(i + ", " + thw + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷却水流量, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 40; i <= 100; i += 5)
          {
            double rt = i / 100d;
            ads.Update(22, mchw, 27, mcdw * rt, thw, mhw);
            sWriter.WriteLine(thw + ", " + rt + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, 冷却水入口温度, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 55; thw <= 65; thw += 5)
        {
          for (int i = 24; i <= 32; i++)
          {
            ads.Update(22, mchw, i, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + i + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }

        sWriter.WriteLine("温水入口温度, サイクル周期比率, COP, 冷凍能力, 吸着温度, 脱着温度, 冷水出口温度, 吸着量（吸着時）, 吸着量（脱着時）");
        for (int thw = 45; thw <= 55; thw += 2)
        {
          for (int i = 2; i <= 10; i++)
          {
            ads.CyclingTimeRate = i * 0.5;
            ads.Update(22, mchw, 27, mcdw, thw, mhw);
            sWriter.WriteLine(thw + ", " + ads.CyclingTimeRate + ", " + ads.COP.ToString("F3") + ", " + ads.CoolingLoad.ToString("F3") + ", " +
              +ads.CoolingWaterOutletTemperature + ", " + ads.HotWaterOutletTemperature + ", " + ads.ChilledWaterOutletTemperature + ", "
              + ads.WaterContent_Adsorption + ", " + ads.WaterContent_Desorption);
          }
        }
      }
    }
    
  }
}
